@@ -386,7 +386,10 @@ void GpxParser::parseCache(QXmlStreamReader &xml, Cache &cache) {
 	Description hints;
 	QString hintsText;
 	parseString(xml, hintsText);
-	hints.set(false, hintsText);
+	if(hintsText.simplified().size() > 0) {
+	  hints.set(false, hintsText);
+	  cache.setHint(hints);
+	}
       } else if(xml.name() == "attributes") 
 	parseAttributes(xml, cache);
       else if(xml.name() == "logs") 
