@@ -24,7 +24,8 @@ class Waypoint : public QLandmark {
  public:
   enum Type {
     Unknown, 
-    Multistage, Parking, Final, Question, Trailhead, Refpoint
+    Multistage, Parking, Final, Question, Trailhead, Refpoint,
+    Custom
   };
   
   Waypoint();
