@@ -12,7 +12,7 @@
 <context>
     <name>CacheProvider</name>
     <message>
-        <location filename="../src/cacheprovider.cpp" line="378"/>
+        <location filename="../src/cacheprovider.cpp" line="379"/>
         <source>&amp;Cache Provider</source>
         <translation>&amp;Cache-Datenquelle</translation>
     </message>
@@ -68,72 +68,77 @@
 <context>
     <name>CoordinateTool</name>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="119"/>
+        <location filename="../src/coordinatetool.cpp" line="124"/>
         <source>New waypoint</source>
         <translation>Neuer Wegpunkt</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="130"/>
+        <location filename="../src/coordinatetool.cpp" line="135"/>
         <source>Name:</source>
         <translation>Name:</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="139"/>
+        <location filename="../src/coordinatetool.cpp" line="144"/>
         <source>Description:</source>
         <translation>Beschreibung:</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="164"/>
+        <location filename="../src/coordinatetool.cpp" line="169"/>
         <source>New Coordinate</source>
         <translation>Neue Koordinate</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="165"/>
+        <location filename="../src/coordinatetool.cpp" line="170"/>
         <source>Edit Coordinate</source>
         <translation>Koordinate bearbeiten</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="328"/>
+        <location filename="../src/coordinatetool.cpp" line="333"/>
         <source>S</source>
         <translation>S</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="329"/>
+        <location filename="../src/coordinatetool.cpp" line="334"/>
         <source>N</source>
         <translation>N</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="345"/>
+        <location filename="../src/coordinatetool.cpp" line="350"/>
         <source>W</source>
         <translation>W</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="346"/>
+        <location filename="../src/coordinatetool.cpp" line="351"/>
         <source>E</source>
         <translation>O</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="433"/>
+        <location filename="../src/coordinatetool.cpp" line="438"/>
         <source>New</source>
         <translation>Neu</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="436"/>
+        <location filename="../src/coordinatetool.cpp" line="441"/>
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="440"/>
+        <location filename="../src/coordinatetool.cpp" line="445"/>
         <source>Delete</source>
         <translation>Löschen</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="473"/>
+        <location filename="../src/coordinatetool.cpp" line="449"/>
+        <source>Copy to clipboard</source>
+        <translation>Kopiere in Zwischenablage</translation>
+    </message>
+    <message>
+        <location filename="../src/coordinatetool.cpp" line="481"/>
         <source>Latitude</source>
         <translation>Breite</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="478"/>
+        <location filename="../src/coordinatetool.cpp" line="486"/>
         <source>Longitude</source>
         <translation>Länge</translation>
     </message>
@@ -162,22 +167,27 @@
         <translation>Kein gültiger Login angegeben, Cache-Positionen werden ungenau sein!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="222"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="207"/>
+        <source>!Network connection failed, please make sure you are connected to the internet and restart CacheMe!</source>
+        <translation>!Netzwerkverbindung fehlgeschlagen. Bitte stellen Sie sicher, dass Sie mit dem Netzwerk verbunden sind und starten Sie CacheMe neu!</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="247"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="273"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="297"/>
         <source>Login failed!</source>
         <translation>Einloggen fehlgeschlagen!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="425"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="449"/>
         <source>Unable to determine cache id!</source>
         <translation>Cache-ID nicht feststellbar!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="453"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="477"/>
         <source>Unable to determine cache guid!</source>
         <translation>Cache-Guid nicht feststellbar!</translation>
     </message>
@@ -491,7 +501,7 @@
         <translation type="obsolete">Öffne &quot;%1&quot; im Browser ...</translation>
     </message>
     <message>
-        <location filename="../src/mapwidget.cpp" line="356"/>
+        <location filename="../src/mapwidget.cpp" line="379"/>
         <source>Displayed cache data is %1 weeks old!</source>
         <translation>Angezeigte Cache-Daten sind %1 Wochen alt!</translation>
     </message>
@@ -499,7 +509,7 @@
 <context>
     <name>NavigationWindow</name>
     <message>
-        <location filename="../src/navigationwindow.cpp" line="72"/>
+        <location filename="../src/navigationwindow.cpp" line="111"/>
         <source>Distance</source>
         <translation>Entfernung</translation>
     </message>
@@ -508,12 +518,12 @@
         <translation type="obsolete">Aktuelle Koordinate:</translation>
     </message>
     <message>
-        <location filename="../src/navigationwindow.cpp" line="61"/>
+        <location filename="../src/navigationwindow.cpp" line="100"/>
         <source>Latitude</source>
         <translation>Breite</translation>
     </message>
     <message>
-        <location filename="../src/navigationwindow.cpp" line="63"/>
+        <location filename="../src/navigationwindow.cpp" line="102"/>
         <source>Longitude</source>
         <translation>Länge</translation>
     </message>
@@ -522,7 +532,7 @@
         <translation type="obsolete">Cache-Koordinate:</translation>
     </message>
     <message>
-        <location filename="../src/navigationwindow.cpp" line="45"/>
+        <location filename="../src/navigationwindow.cpp" line="77"/>
         <source>Navigation</source>
         <translation>Navigation</translation>
     </message>
@@ -554,32 +564,32 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/mapbubble.cpp" line="258"/>
+        <location filename="../src/mapbubble.cpp" line="259"/>
         <source>Difficulty</source>
         <translation>Schwierigkeit</translation>
     </message>
     <message>
-        <location filename="../src/mapbubble.cpp" line="259"/>
+        <location filename="../src/mapbubble.cpp" line="260"/>
         <source>Terrain</source>
         <translation>Gelände</translation>
     </message>
     <message>
-        <location filename="../src/mapbubble.cpp" line="262"/>
+        <location filename="../src/mapbubble.cpp" line="263"/>
         <source>Placed on</source>
         <translation>Gelegt am</translation>
     </message>
     <message>
-        <location filename="../src/mapbubble.cpp" line="264"/>
+        <location filename="../src/mapbubble.cpp" line="265"/>
         <source>by</source>
         <translation>von</translation>
     </message>
     <message>
-        <location filename="../src/mapbubble.cpp" line="266"/>
+        <location filename="../src/mapbubble.cpp" line="267"/>
         <source>Placed by</source>
         <translation>Gelegt von</translation>
     </message>
     <message>
-        <location filename="../src/mapbubble.cpp" line="271"/>
+        <location filename="../src/mapbubble.cpp" line="272"/>
         <source>Container</source>
         <translation>Behälter</translation>
     </message>
@@ -1247,7 +1257,7 @@
         <translation>&lt;unbekannt&gt;</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="169"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="171"/>
         <source>GPL version 2
 Copyright 2011 by Till Harbaum
 QSgml parts Copyright 2010 by Andreas Lehmann</source>
