@@ -8,6 +8,10 @@
 #include <QVBoxLayout>
 #include <QLabel>
 #include <QNetworkCookie>
+#include <QHostInfo>
+#include <QNetworkConfigurationManager>
+#include <QNetworkSession>
+#include <QNetworkInterface>
 
 #include "gcbrowser.h"
 #include "gcparser.h"
@@ -20,7 +24,7 @@
 class GcUrl : public QUrl {
 public:
   GcUrl(const QString &url, bool useHttps = false) : 
-    QUrl("http" + QString(useHttps?"":"") + "://www.geocaching.com" + url) {}
+    QUrl("http" + QString(useHttps?"s":"") + "://www.geocaching.com" + url) {}
 };
 
 // the GcNetworkRequest pre-sets some header values
@@ -88,7 +92,7 @@ void GcBrowser::requestUserToken() {
 void GcBrowser::prepareLogin() {
   if(loginIsValid()) {
     GcNetworkRequest request;
-    request.setUrl(GcUrl("/login/", true));
+    request.setUrl(GcUrl("/login/default.aspx", true));
     this->m_posted = QString();
     QNetworkReply *reply = this->m_manager->get(request);    
     emit notifyBusy(true);
@@ -104,17 +108,18 @@ void GcBrowser::prepareLogin() {
 void GcBrowser::doLogin() {
 
   GcNetworkRequest request;
-  request.setUrl(GcUrl("/login/", true));
-  
+  request.setUrl(GcUrl("/login/default.aspx", true));
+
   QString data = m_lastViewState;
-  data += "&ctl00$SiteContent$cbRememberMe=on";
-  data += "&ctl00$SiteContent$btnSignIn=Login";
-  data += "&ctl00$SiteContent$tbUsername=" + 
+  data += "&ctl00$ContentBody$cbRememberMe=on";
+  data += "&ctl00$ContentBody$btnSignIn=Login";
+  data += "&ctl00$ContentBody$tbUsername=" + 
     QUrl::toPercentEncoding(m_name);
-  data += "&ctl00$SiteContent$tbPassword=" + 
+  data += "&ctl00$ContentBody$tbPassword=" + 
     QUrl::toPercentEncoding(m_password);
  
   this->m_posted = data;
+
   m_manager->post(request, data.toUtf8());
 
   emit notifyBusy(true);
@@ -122,7 +127,7 @@ void GcBrowser::doLogin() {
 }
 
 GcBrowser::GcBrowser() : m_initialized(false), m_cacheList(PLUGIN_NAME), 
-		   m_state(Idle), m_currentRequest(None) {
+		 m_state(Idle), m_currentRequest(None), m_pendingReload(false) {
   qDebug() << __PRETTY_FUNCTION__;
 
   // try to get credentials from qsettings
@@ -135,6 +140,20 @@ GcBrowser::GcBrowser() : m_initialized(false), m_cacheList(PLUGIN_NAME),
   // setup network manager and listen for its replies
   this->m_manager = new QNetworkAccessManager(this);
 
+  // get current list of ip addresses
+  QNetworkConfigurationManager mgr;
+  QNetworkSession session (mgr.defaultConfiguration());
+  QNetworkInterface ninter = session.interface();
+  // the next statement gives you a funny name on windows
+  qDebug() << "Ifname" << ninter.name();
+  qDebug() << "Ifaddresses" << ninter.allAddresses();
+ 
+  // this provides two ip addresses (1 ipv4 and 1 ipv6) at least on my machine
+  QList<QNetworkAddressEntry> laddr = ninter.addressEntries();
+  for ( QList<QNetworkAddressEntry> ::const_iterator it = laddr.begin(); it != laddr.end(); ++it ) {
+    qDebug() << "Entry" << it->ip();
+  }
+
   // try to load stored cookies
   QList<QNetworkCookie> cookies;
   settings.beginGroup(PLUGIN_NAME);
@@ -197,18 +216,40 @@ bool GcBrowser::busy() {
 }
 
 void GcBrowser::replyFinished(QNetworkReply *reply) {
+
+  if(reply->error() == QNetworkReply::UnknownNetworkError) {
+    qDebug() << __FUNCTION__ << "bailing out due to unknown error";
+    error("");  // clear error to make sure more messages are displayed
+    error(tr("!Network connection failed, "
+	     "please make sure you are connected to the internet and restart CacheMe!"));
+    return;
+  }
+
   QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
   if (!redirect.isEmpty()) {
-    qDebug() << "received redirect to" << redirect;
+    QString allData = QString::fromUtf8(reply->readAll());
+
+    if(redirect.host().isEmpty())
+      redirect.setHost("www.geocaching.com");
+    
+    if(redirect.scheme().isEmpty())
+      redirect.setScheme("https");
+
+    qDebug() << __FUNCTION__ << "redirect to" << redirect;
 
     GcNetworkRequest request;
     request.setUrl(redirect);
     QNetworkReply *newReply;
 
+    // http 1.1 always builds a get request from a redirected get or post
+#if 0
     if(this->m_posted.isEmpty())
       newReply = this->m_manager->get(request);
     else
       newReply = this->m_manager->post(request, this->m_posted.toUtf8());
+#else
+    newReply = this->m_manager->get(request);
+#endif
     
     if(newReply->error()) replyFinished(newReply);
     reply->deleteLater();
@@ -241,7 +282,6 @@ void GcBrowser::replyFinished(QNetworkReply *reply) {
       m_state = Idle;
 
     } else if(this->m_state == SentLoginGET || this->m_state == SentLoginPOST) {
-      //      qDebug() << allData;
 
       // check if we are successfully logged in
       if (allData.contains("You are logged in as")) {
@@ -251,7 +291,7 @@ void GcBrowser::replyFinished(QNetworkReply *reply) {
 	settings.beginGroup(PLUGIN_NAME);
 	settings.beginGroup("Cookies");
 	QList<QNetworkCookie> cookies = 
-	  this->m_manager->cookieJar()->cookiesForUrl(GcUrl(""));
+	  this->m_manager->cookieJar()->cookiesForUrl(GcUrl("", true));
 
 	// save all non-session cookies
 	foreach(QNetworkCookie cookie, cookies) 
@@ -295,6 +335,14 @@ void GcBrowser::replyFinished(QNetworkReply *reply) {
 	  if(!gcParser.decodeOverview(allData, m_cacheList, m_bigArea))
 	    error(gcParser.error());
 
+	  // append saved Waypoints if they belong to one of the caches
+	  // returned
+	  for(QList<Cache>::iterator i = m_cacheList.begin(); 
+	      i != m_cacheList.end(); ++i ) 
+	    if(i->name() == m_lastWaypointsName)
+	      foreach(const Waypoint wpt, m_lastWaypoints)
+		i->appendWaypoint(wpt);
+
 	  // always emit the list, even if it's empty, so existing caches
 	  // get cleared
 	  emit replyOverview(m_cacheList);
@@ -308,9 +356,19 @@ void GcBrowser::replyFinished(QNetworkReply *reply) {
 	  break;
 	  
 	case Detail: 
-	  if(gcHtmlParser.decode(allData, m_cache)) 
+	  if(gcHtmlParser.decode(allData, m_cache)) {
 	    emit replyDetail(m_cache);
-	  else
+
+	    if(m_lastWaypointsName != m_cache.name()) {
+	      // save waypoints for future use
+	      m_lastWaypointsName = m_cache.name();
+	      m_lastWaypoints = m_cache.waypoints();
+
+	      // request reload of main map to update waypoints
+	      m_pendingReload = true;
+	    }
+
+	  } else
 	    error(gcHtmlParser.error());
 	  break;
 	  
@@ -329,6 +387,11 @@ void GcBrowser::replyFinished(QNetworkReply *reply) {
 
   emit notifyBusy(false);
   reply->deleteLater();
+
+  if(m_pendingReload) {
+    emit reload();
+    m_pendingReload = false;
+  }
 }
 
 void GcBrowser::postJson(const QString &post) {
@@ -343,16 +406,38 @@ void GcBrowser::postJson(const QString &post) {
   emit notifyBusy(true);
 }
 
-void GcBrowser::processRequestOverview(const QGeoBoundingBox &area) {
+void GcBrowser::processRequestOverview(const QGeoBoundingBox &area, const int) {
   qDebug() << __PRETTY_FUNCTION__;
 
+  // check if we can fulfil request from cachelist
+  if(m_cacheBox.contains(area) && m_cacheList.size() > 0) {
+    qDebug() << __FUNCTION__ << "can fulfil request from cache";
+
+    for(QList<Cache>::iterator i = m_cacheList.begin(); 
+	i != m_cacheList.end(); ++i ) 
+      if(i->name() == m_lastWaypointsName && i->waypoints().size() == 0)
+	foreach(const Waypoint wpt, m_lastWaypoints)
+	  i->appendWaypoint(wpt);
+    
+    // always emit the list, even if it's empty, so existing caches
+    // get cleared
+    emit done();
+    emit replyOverview(m_cacheList);
+    emit next();
+    
+    return;
+  }  
+
+  m_cacheBox = area;
+
   Q_ASSERT(this->m_currentRequest == None);
   this->m_currentRequest = Overview;
   
   // check if bounding box doesn't exceed limits (40km diagonally)
   this->m_bigArea = area.topLeft().distanceTo(area.bottomRight()) > 40000;
   
-  // build request string
+  // build request string. Isn't there a way to not request "owned" and
+  // "found" ones?
   postJson("{\"dto\":{\"data\":{\"c\":1,\"m\":\"\",\"d\":\"" + 
 	   QString::number(area.topLeft().latitude()) + "|" + 
 	   QString::number(area.bottomRight().latitude()) + "|" + 
@@ -455,9 +540,12 @@ void GcBrowser::createConfig(QDialog *parent, QVBoxLayout *) {
 
 // send an error message to the cache provider
 void GcBrowser::error(const QString &msg) {
-  if(!msg.isEmpty())
-    emit replyError(tr(PLUGIN_NAME) + ": " + msg);
-  else
+  if(!msg.isEmpty()) {
+    if(msg.at(0) == QChar('!')) 
+      emit replyError("!" + tr(PLUGIN_NAME) + ": " + QString(msg).remove(0,1));
+    else
+      emit replyError(tr(PLUGIN_NAME) + ": " + msg);
+  } else
     emit replyError("");
 }
 
