@@ -25,7 +25,7 @@ public:
   void createConfig(QDialog *, QVBoxLayout*);
 
   bool busy();
-  void processRequestOverview(const QGeoBoundingBox &);
+  void processRequestOverview(const QGeoBoundingBox &, const int);
   void processRequestInfo(const QString &);
   void processRequestDetail(const QString &);
 
