@@ -21,7 +21,7 @@ class CacheProviderPlugin {
   virtual void createConfig(QDialog *, QVBoxLayout*) = 0;
 
   virtual bool busy() = 0;
-  virtual void processRequestOverview(const QGeoBoundingBox &) = 0;
+  virtual void processRequestOverview(const QGeoBoundingBox &, int) = 0;
   virtual void processRequestInfo(const QString &) = 0;
   virtual void processRequestDetail(const QString &) = 0;
 };
