@@ -12,7 +12,10 @@
 #include <QDialogButtonBox>
 #include <QComboBox>
 #include <QMenu>
+#include <QApplication>
+#include <QClipboard>
 #include <math.h>
+#include <QAbstractItemView>
 
 #include "coordinatetool.h"
 #include "pickermanager.h"
@@ -77,6 +80,9 @@ void CoordinateTool::coordinatesAccepted() {
     // a newly created entry can be edited and deleted
     m_actionEdit->setEnabled(true);
     m_actionDelete->setEnabled(true);
+
+    m_wpt.setType(Waypoint::Custom);
+    emit typeChanged(m_wpt);
   } else {
     m_wptDb->update(m_wpt);
     // no need to update combobox as name cannot be changed
@@ -441,6 +447,9 @@ QWidget *CoordinateTool::createWidget(const QString &title) {
   m_actionDelete->setEnabled(false);
   connect(m_actionDelete, SIGNAL(triggered()), this, SLOT(deleteTriggered()));
 
+  QAction *actionCopy = toolMenu->addAction(tr("Copy to clipboard"));
+  connect(actionCopy, SIGNAL(triggered()), this, SLOT(copyTriggered()));
+
   button->setMenu(toolMenu);
   button->setPopupMode(QToolButton::InstantPopup);
 
@@ -452,6 +461,11 @@ QWidget *CoordinateTool::createWidget(const QString &title) {
   connect(m_cBox, SIGNAL(activated(const QString &)), 
 	  this, SLOT(selectWaypoint(const QString &)));
 
+  m_cBox->view()->setTextElideMode (Qt::ElideRight);
+  QSizePolicy sp1 (QSizePolicy::Ignored, QSizePolicy::Fixed, QSizePolicy::ComboBox);
+  sp1.setHorizontalStretch (2);
+  m_cBox->setSizePolicy (sp1);
+
   m_cBox->addItem(m_cache.description());
 
   foreach(Waypoint wpt, m_cache.waypoints())
@@ -528,6 +542,14 @@ void CoordinateTool::editTriggered() {
   m_dialog->exec();
 }
 
+void CoordinateTool::copyTriggered() {
+  qDebug() << __FUNCTION__ << m_coo;
+
+  // copy a textual represenation of the coordinate to the clipboard
+  QApplication::clipboard()->setText(
+     latitudeString(m_coo) + " " + longitudeString(m_coo));
+}
+
 void CoordinateTool::deleteTriggered() {
   qDebug() << __FUNCTION__;
 
