@@ -45,7 +45,8 @@ void MainWindow::about() {
 
 
 MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) : 
-  CustomWindow("MainWindow", parent), m_locationProvider(locationProvider) {
+  CustomWindow("MainWindow", parent), m_locationProvider(locationProvider),
+  m_lastFlags(0) {
 
   qDebug() << __FUNCTION__;
   m_cacheProvider = new CacheProvider(this);
@@ -104,8 +105,8 @@ MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) :
   QObject::connect(this->m_cacheProvider, SIGNAL(notifyBusy(bool)),
 		   this, SLOT(setBusy(bool)));
 
-  QObject::connect(this->m_mapWidget, SIGNAL(mapChanged()),
-		   this, SLOT(reloadCaches()));
+  QObject::connect(this->m_mapWidget, SIGNAL(mapChanged(const int)),
+		   this, SLOT(reloadCaches(const int)));
 
   QObject::connect(this->m_mapWidget, SIGNAL(showMessage(const QString &)),
 		   this, SLOT(statusMessage(const QString &)));
@@ -178,7 +179,14 @@ void MainWindow::detailCache(const QString &name) {
 
 void MainWindow::reloadCaches() {
   // request new caches for the maps new viewport
-  m_cacheProvider->requestOverview(this->m_mapWidget->viewport());
+  m_cacheProvider->requestOverview(this->m_mapWidget->viewport(), m_lastFlags);
+}
+
+void MainWindow::reloadCaches(const int flags) {
+  m_lastFlags = flags;
+
+  // request new caches for the maps new viewport
+  m_cacheProvider->requestOverview(this->m_mapWidget->viewport(), flags);
 }
 
 void MainWindow::updateCaches(const CacheList &cacheList) {
