@@ -27,6 +27,7 @@ class MainWindow : public CustomWindow {
   void statusMessage(const QString &);
   // called from map widget whenever the viewport changed
   void reloadCaches();
+  void reloadCaches(const int);
   // called from cacheprovider
   void updateCaches(const CacheList &);
   void displayError(const QString &);
@@ -51,6 +52,7 @@ class MainWindow : public CustomWindow {
   QGraphicsView *m_view;
 
   WaypointDb *m_wptDb;
+  int m_lastFlags;
 };
 
 #endif
