@@ -14,11 +14,14 @@ class MapBubble : public QGeoMapPixmapObject {
 
  public:
   MapBubble(const QGraphicsGeoMap *, bool, const Cache &);
+  MapBubble(const QGraphicsGeoMap *, bool, const Waypoint &);
   Cache cache() const;
+  Waypoint wpt() const;
 
  private:
   qreal calculateTipOffset(const QGraphicsGeoMap *, const QGeoCoordinate &, const QSize &);
   Cache m_cache;
+  Waypoint m_wpt;
 };
 
 #endif // MAPBUBBLE_H
