@@ -8,6 +8,7 @@
 
 #include "mapwidget.h"
 #include "custompixmap.h"
+#include "cacheprovider.h"
 #include "config.h"
 
 #if(QTM_VERSION < 0x010100)
@@ -37,6 +38,7 @@ MapWidget::MapWidget(QGeoMappingManager *mgr) :
 			      QGraphicsGeoMap::StreetMap).toInt());
   m_gpsLocked = settings.value("GpsLocked", false).toBool();
   m_hiRez = settings.value("HiRez", false).toBool();
+  m_hideOwn = settings.value("HideOwn", false).toBool();
   m_precisionAlpha = settings.value("PrecisionAlpha", 32).toInt();
   settings.endGroup();
   if(m_hiRez) m_iconLoader = new IconLoader(Config::MAP_WIDGET_ICON_SIZE_HIREZ);
@@ -275,7 +277,7 @@ void MapWidget::mouseReleaseEvent(QGraphicsSceneMouseEvent* event) {
 	m_customWpts =  m_wptDb->get(clickedCache);
      
       /* update caches to show waypoints of selected cache if present */
-      emit mapChanged();
+      emit mapChanged(m_hideOwn?(CacheProvider::NoFound|CacheProvider::NoOwned):CacheProvider::None);
  
       if(!clickedWaypoint.coordinate().isValid()) 
 	emit cacheClicked(clickedCache);
@@ -384,15 +386,19 @@ void MapWidget::updateCaches(const CacheList &cacheList) {
   // draw all new caches
   QList<Cache>::const_iterator i;
   for( i = cacheList.begin(); i != cacheList.end(); ++i ) {
-    bool isSelected = (i->name() == m_selectedCache);
+    // show if nno found/owned are to be hidden or if the cache is neither found nor owned 
+    if(!m_hideOwn || (!i->owned().isSetAndTrue() && !i->found().isSetAndTrue())) {
 
-    // highlight if cache has waypoints
-    m_cacheGroup->addChildObject(new MapCacheObject(m_iconLoader, *i, 
-     isSelected && ((i->waypoints().size() > 0) || (m_customWpts.size() > 0))));
-				 
-    // also draw waypoints of selected cache
-    if(isSelected) 
-      m_selectedWaypoints = i->waypoints();
+      bool isSelected = (i->name() == m_selectedCache);
+
+      // highlight if cache has waypoints
+      m_cacheGroup->addChildObject(new MapCacheObject(m_iconLoader, *i, 
+	      isSelected && ((i->waypoints().size() > 0) || (m_customWpts.size() > 0))));
+      
+      // also draw waypoints of selected cache
+      if(isSelected) 
+	m_selectedWaypoints = i->waypoints();
+    }
   }
 
   // draw all waypoints from list
@@ -437,7 +443,7 @@ void MapWidget::reloadTimerExpired() {
   if(m_currentViewport != viewport()) {
     m_lastUpdateCenter = center();
 
-    emit mapChanged();
+    emit mapChanged(m_hideOwn?(CacheProvider::NoFound|CacheProvider::NoOwned):CacheProvider::None);
     m_currentViewport = viewport();
   }
 }
@@ -461,6 +467,8 @@ void MapWidget::positionUpdated(const QCompassReading *reading) {
 
       // todo: rotate markerIcon
 
+      
+
       if(m_gpsMarker) m_gpsMarker->setPixmap(*markerIcon);
       m_compass = newVal;
     }
@@ -545,7 +553,22 @@ void MapWidget::setHiRez(bool hiRez) {
       m_iconLoader = new IconLoader(Config::MAP_WIDGET_ICON_SIZE);
 
     // this will also cause the overlay to redraw
-    emit mapChanged();
+    emit mapChanged(m_hideOwn?(CacheProvider::NoFound|CacheProvider::NoOwned):CacheProvider::None);
+  }
+}
+
+bool MapWidget::hideOwn() const {
+  return m_hideOwn;
+}
+
+void MapWidget::setHideOwn(bool hideOwn) {
+  qDebug() << __FUNCTION__;
+
+  if(m_hideOwn != hideOwn) {
+    m_hideOwn = hideOwn;
+
+    // this will also cause the overlay to redraw
+    emit mapChanged(m_hideOwn?(CacheProvider::NoFound|CacheProvider::NoOwned):CacheProvider::None);
   }
 }
 
@@ -559,7 +582,7 @@ void MapWidget::reloadCustomWaypoints() {
     // if there weren't any custom waypoints and there now aren't
     // we have nothing to redraw
     if((m_customWpts.size() != 0) || hadCustomWpts) 
-      emit mapChanged();  
+      emit mapChanged(m_hideOwn?(CacheProvider::NoFound|CacheProvider::NoOwned):CacheProvider::None);
   }
 }
 
