@@ -34,10 +34,12 @@ class MapWidget : public QGraphicsGeoMap {
   void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget * = 0);
   bool hiRez() const;
   void setHiRez(bool);
+  bool hideOwn() const;
+  void setHideOwn(bool);
   void setWaypointDb(WaypointDb *);
 
  signals:
-  void mapChanged();
+  void mapChanged(const int);
   void cacheClicked(const QString &);
   void detailClicked(const QString &);
   void showMessage(const QString &);
@@ -101,6 +103,7 @@ class MapWidget : public QGraphicsGeoMap {
   bool m_posIsValid;
   bool m_gpsLocked;
   bool m_hiRez;
+  bool m_hideOwn;
   int m_precisionAlpha;
   QString m_selectedCache;
   QList<Waypoint> m_selectedWaypoints;
