@@ -36,6 +36,38 @@ private:
   QLabel *m_left, *m_right;
 };
 
+#if 0
+class SizeCompass: public Compass {
+public:
+  SizeCompass(const Cache &cache, QWidget *parent): 
+    Compass(cache, parent), m_other(NULL) {
+  }
+
+  void resizeEvent(QResizeEvent *) {
+
+    // check if parent is really wider than high
+    if(parentWidget()->size().width() > 
+       parentWidget()->size().height()) {
+      // width should then be at least half the total width
+      int minWidth = (width() + m_other->width())/2;
+      
+      if(minWidth > height())
+	minWidth = height();
+
+      setMinimumWidth(minWidth);
+    } else
+      setMinimumWidth(0);
+  }
+
+  void setOther(QWidget *other) {
+    m_other = other;
+  }
+  
+private:
+  QWidget *m_other;
+};
+#endif
+
 NavigationWindow::NavigationWindow(const Cache &cache, 
 	   LocationProvider *locationProvider, 
 	   WaypointDb *wptDb, QWidget *parent) : 
@@ -46,12 +78,19 @@ NavigationWindow::NavigationWindow(const Cache &cache,
 
   SwapBox *sbox = new SwapBox();
 
+  if(!m_screenSaver.setScreenSaverInhibit())
+    qDebug() << __FUNCTION__ << "disabling the screensaver failed!";
+
+  // try to force the compass to be at least as wide
+  // as the infos on the right (bottom)
+
   // left/top: the compass
   Compass *compass = new Compass(m_cache, this);
   sbox->addWidget(compass);
 
   // right/bottom: the textual info
-  QWidget *vbox = new QWidget;
+  QWidget *vbox = new QWidget(compass);
+  //  compass->setOther(vbox);
   QVBoxLayout *layout = new QVBoxLayout;
   layout->setContentsMargins(0,0,0,0);
   layout->setSpacing(0);
