@@ -4,6 +4,7 @@
 #include <QDialog>
 #include <QComboBox>
 #include <QLineEdit>
+#include <QCheckBox>
 
 #include "cacheprovider.h"
 #include "mapwidget.h"
@@ -23,6 +24,8 @@ Q_OBJECT
   QComboBox *m_serviceCombo;
   QLineEdit *m_name;
   QLineEdit *m_password;
+  QCheckBox *m_hiRez;
+  QCheckBox *m_hideOwn;
 };
 
 #endif
